;; This "home-environment" file can be passed to 'guix home reconfigure'
;; to reproduce the content of your profile.  This is "symbolic": it only
;; specifies package names.  To reproduce the exact same profile, you also
;; need to capture the channels being used, as returned by "guix describe".
;; See the "Replicating Guix" section in the manual.

(use-modules (gnu home)
             (gnu packages)
             (gnu packages vim)
             (gnu packages gcc)
             (gnu services)
             (guix packages)
             (guix gexp)
             (gnu home services shells)
             (gnu home services))

(define my-neovim
  (package
    (inherit neovim)
    (native-inputs
      (modify-inputs (package-native-inputs neovim)
                     (prepend gcc-12)))))

(home-environment
  ;; Below is the list of packages that will show up in your
  ;; Home profile, under ~/.guix-home/profile.
  (packages (append (specifications->packages (list "bat"
                                                    "qrencode"
                                                    "binutils"
                                                    "gcc-toolchain"
                                                    "borg"
                                                    "python-msgpack"
                                                    "libreoffice"
                                                    "flatpak"
                                                    "gnupg"
                                                    "lsof"
                                                    "pavucontrol"
                                                    "bind:utils"
                                                    "firefox"
                                                    "irssi"
                                                    "font-cns11643"
                                                    "syncthing"
                                                    "perl"
                                                    "tor"
                                                    "unzip"
                                                    "alacritty"
                                                    "htop"
                                                    "curl"
                                                    "pandoc"
                                                    "texlive-base"
                                                    "texlive-txfonts"
                                                    "texlive-amsfonts"
                                                    "texlive-lm"
                                                    "texlive-lm-math"
                                                    "texlive-generic-iftex"
                                                    "texlive-unicode-math"
                                                    "texlive-fontspec"
                                                    "texlive-xcolor"
                                                    "texlive-latex-geometry"
                                                    "texlive-hyperref"
                                                    "texlive-latex-parskip"
                                                    "texlive-etoolbox"
                                                    "zathura"
                                                    "zathura-pdf-mupdf"
                                                    "fzf"
                                                    "weechat"
                                                    "icedove-minimal"
                                                    "gimp"
                                                    "python"
                                                    "python:tk"
                                                    ;"tk"
                                                    ;"tcl"
                                                    "python-lsp-server"
                                                    "sqlite"
                                                    "git"))
                    (list my-neovim)))

  ;; Below is the list of Home services.  To search for available
  ;; services, run 'guix home search KEYWORD' in a terminal.
  (services
   (list (service home-bash-service-type
                  (home-bash-configuration
                   (aliases '(("grep" . "grep --color=auto") ("ll" . "ls -l")
                              ("ls" . "ls -p --color=auto")
                              ("python" . "python3")))
                   (bashrc (list (local-file
                                  "/home/ryan/.config/guix/home-config/bashrc"
                                  "bashrc")))
                   (bash-profile (list (local-file
                                        "/home/ryan/.config/guix/home-config/bash_profile"
                                        "bash_profile")))))
         (service home-xdg-configuration-files-service-type
                  `(("nvim/init.vim" ,(local-file "nvim/config/init.vim"))
                    ("nvim/after/ftplugin/markdown/custom.vim" ,(local-file "nvim/config/after/ftplugin/markdown/custom.vim")) ))
         (service home-files-service-type
                  `((".local/share/nvim/site/autoload/plug.vim" ,(local-file "nvim/plugin-manager/plug.vim")) )))))
